use actix_web::{error::ErrorInternalServerError, HttpResponse, Result};
use mime_guess::MimeGuess;

use crate::app_state::AppState;
use crate::s3_utils::check_file_exists;

/// Функция для обслуживания файла по заданному пути.
pub async fn serve_file(filepath: &str, state: &AppState) -> Result<HttpResponse, actix_web::Error> {
    if filepath.is_empty() {
        return Err(ErrorInternalServerError("Filename is empty".to_string()));
    }

    // Проверяем наличие файла в Storj S3
    let exists = check_file_exists(&state.storj_client, &state.bucket, &filepath).await?;
    if !exists {
        return Err(ErrorInternalServerError(format!("File {} not found in Storj", filepath)));
    }

    // Получаем объект из Storj S3
    let get_object_output = state
        .storj_client
        .get_object()
        .bucket(&state.bucket)
        .key(filepath)
        .send()
        .await
        .map_err(|_| ErrorInternalServerError(format!("Failed to get {} object from Storj", filepath)))?;

    let data: aws_sdk_s3::primitives::AggregatedBytes = get_object_output
        .body
        .collect()
        .await
        .map_err(|_| ErrorInternalServerError("Failed to read object body"))?;

    let data_bytes = data.into_bytes();
    let mime_type = MimeGuess::from_path(&filepath).first_or_octet_stream();

    Ok(HttpResponse::Ok()
        .content_type(mime_type.as_ref())
        .body(data_bytes))
}
